@@ -2,10 +2,13 @@
 Test LTI web components of the application
 """
 import json
+import logging
 import os
 import time
 import unittest
 
+from mock import patch
+
 import xsiftx.config
 from xsiftx.config import get_config, get_consumer
 from xsiftx.util import get_sifters
@@ -40,7 +43,7 @@ class TestLTIWebApp(unittest.TestCase):
             'oauth_consumer_key': consumer['key'],
             'oauth_signature_method': 'PLAINTEXT',
             'oauth_version': '1.0',
-            'oauth_signature': '{0}&'.format(consumer['secret']),
+            'oauth_signature': '{0}&'.format(consumer.get('secret', '')),
             'oauth_timestamp': str(int(time.time())),
             'oauth_nonce': '123456789',
             'context_id': 'MITx/A.we/some'
@@ -71,6 +74,7 @@ class TestLTIWebApp(unittest.TestCase):
                  'allowed_sifters': ['test_sifters']},
                 {'key': 'test_course2',
                  'secret': 'test_secret2', },
+                {'key': 'testo', },
             ]
         )
 
@@ -95,6 +99,45 @@ class TestLTIWebApp(unittest.TestCase):
         os.environ['XSIFTX_CONFIG'] = conf_save
         xsiftx.config.CONFIG_PATHS = config_path_save
 
+    @patch('xsiftx.lti.oauthstore.log')
+    def test_no_consumers(self, mock_logging):
+        """
+        Make sure we handle a lack of conumers altogether well
+        """
+        saved_consumers = xsiftx.config.settings['consumers']
+        del xsiftx.config.settings['consumers']
+
+        response = self.client.post('/', data=self._oauth_request())
+        self.assertEquals(response.status_code, 401)
+        self.assertTrue(mock_logging.critical.called_with(
+            "No consumers defined in settings."
+            "Have you created a configuration file?"
+        ))
+
+        # Restore
+        xsiftx.config.settings['consumers'] = saved_consumers
+
+    @patch('xsiftx.lti.oauthstore.log')
+    def test_consumer_without_secret(self, mock_logging):
+        """
+        Test a consumer that is missing a secret.
+        """
+        keyless_consumer = 2
+        response = self.client.post(
+            '/',
+            data=self._oauth_request(
+                {'oauth_secret': 'test&'},
+                keyless_consumer
+            )
+        )
+        self.assertEquals(response.status_code, 401)
+        self.assertTrue(mock_logging.critical.called_with(
+            'Consumer {0}, is missing secret'
+            'in settings file, and needs correction.'.format(
+                self.settings['consumers'][keyless_consumer]['key']
+            )
+        ))
+
     def test_lti_authentication(self):
         """
         Test out that LTI authentication is working properly
@@ -136,6 +179,18 @@ class TestLTIWebApp(unittest.TestCase):
             response.data
         )
 
+        # Test https header
+        with xsiftx.web.app.test_client() as client:
+            response = client.post(
+                '/', data=self._oauth_request(),
+                headers={'x-forwarded-proto': 'https'}
+            )
+        self.assertEqual(response.status_code, 401)
+        self.assertTrue(
+            'User does not have a role' in
+            response.data
+        )
+
     def test_lti_staff_decorator(self):
         """
         Make sure that our authorization of role is happening
@@ -148,6 +203,22 @@ class TestLTIWebApp(unittest.TestCase):
             response.data
         )
 
+    def test_reauthorization(self):
+        """
+        Make sure that if my role changes, my access changes as well.
+        """
+        params = self._oauth_request({'roles': 'Student'})
+        response = self.client.post('/', data=params)
+        self.assertEqual(response.status_code, 401)
+        self.assertTrue(
+            'You are not in a staff level role. Access is restricted ' in
+            response.data
+        )
+
+        params = self._oauth_request({'roles': 'Instructor'})
+        response = self.client.post('/', data=params)
+        self.assertEqual(response.status_code, 200)
+
     def test_index(self):
         """
         Several tests of the index page
@@ -288,3 +359,28 @@ class TestLTIWebApp(unittest.TestCase):
         )
         reply_json = json.loads(response.data)
         self.assertTrue(len(reply_json['tasks']), 0)
+
+    def test_logging_level(self):
+        """
+        Tests to make sure logging config happens and handles
+        bad output.
+        """
+        # Check it is the right setting from test config
+        self.assertEqual(self.settings['log_level'], 'debug')
+        level = xsiftx.web.set_log_level()
+        # Check that setting is not applied
+        self.assertEqual(logging.DEBUG, level)
+
+        # Set to invalid level and assert the exception
+        xsiftx.config.settings['log_level'] = 'awesome'
+        with self.assertRaisesRegexp(ValueError, 'Invalid log level.*'):
+            level = xsiftx.web.set_log_level()
+            self.assertIsNone(level)
+
+        # Make sure it is ok not to have a level set
+        del xsiftx.config.settings['log_level']
+        level = xsiftx.web.set_log_level()
+        self.assertIsNone(level)
+
+        # Restore setting
+        xsiftx.config.settings['log_level'] = 'debug'
